@@ -11,7 +11,7 @@ ALPHAFOLD_BASE_URL = "https://alphafold.ebi.ac.uk/api"
 class AlphaFoldRESTTool(BaseTool):
     """
     AlphaFold Protein Structure Database API tool.
-    Generic wrapper for AlphaFold API endpoints defined in alphafold_tools.json.
+    Generic wrapper for AlphaFold API endpoints from alphafold_tools.json.
     """
 
     def __init__(self, tool_config):
@@ -22,6 +22,7 @@ class AlphaFoldRESTTool(BaseTool):
         self.endpoint_template: str = fields["endpoint"]
         self.required: List[str] = parameter.get("required", [])
         self.output_format: str = fields.get("return_format", "JSON")
+        self.auto_query_params: Dict[str, Any] = fields.get("auto_query_params", {})
 
     def _build_url(self, arguments: Dict[str, Any]) -> str | Dict[str, Any]:
         # Example: endpoint_template = "/annotations/{qualifier}.json"
@@ -40,14 +41,18 @@ class AlphaFoldRESTTool(BaseTool):
         # Now url_path = "/annotations/P69905.json"
 
         # Treat all remaining args as query parameters
-        #   "type" wasn’t a placeholder, so it becomes a query param
+        #   "type" wasn't a placeholder, so it becomes a query param
         query_args = {k: v for k, v in arguments.items() if k not in used}
+
+        # Add auto_query_params from config (e.g., type=MUTAGEN)
+        query_args.update(self.auto_query_params)
+
         if query_args:
             from urllib.parse import urlencode
 
             url_path += "?" + urlencode(query_args)
 
-        # Final result = "https://alphafold.ebi.ac.uk/api/annotations/P69905.json?type=MUTAGEN"
+        # Final example: annotations/P69905.json?type=MUTAGEN
         return ALPHAFOLD_BASE_URL + url_path
 
     def _make_request(self, url: str) -> Dict[str, Any]:
@@ -62,9 +67,37 @@ class AlphaFoldRESTTool(BaseTool):
                 },
             )
         except Exception as e:
-            return {"error": "Request to AlphaFold API failed", "detail": str(e)}
+            return {
+                "error": "Request to AlphaFold API failed",
+                "detail": str(e),
+            }
 
         if resp.status_code == 404:
+            # Try to provide more context about 404 errors
+            # Check if protein exists in AlphaFold DB
+            try:
+                qualifier_match = re.search(r"/annotations/([^/]+)\.json", url)
+                if qualifier_match:
+                    accession = qualifier_match.group(1)
+                    base = ALPHAFOLD_BASE_URL
+                    check_url = f"{base}/uniprot/summary/{accession}.json"
+                    check_resp = requests.get(check_url, timeout=10)
+                    if check_resp.status_code == 200:
+                        return {
+                            "error": "No MUTAGEN annotations available",
+                            "reason": (
+                                "Protein exists in AlphaFold DB but "
+                                "has no MUTAGEN annotations"
+                            ),
+                            "endpoint": url,
+                        }
+                    else:
+                        return {
+                            "error": "Protein not found in AlphaFold DB",
+                            "endpoint": url,
+                        }
+            except Exception:
+                pass  # Fall through to generic error
             return {"error": "Not found", "endpoint": url}
         if resp.status_code != 200:
             return {
@@ -98,9 +131,13 @@ class AlphaFoldRESTTool(BaseTool):
         if self.output_format.upper() == "JSON":
             try:
                 data = resp.json()
-                if not data:
+                if not data or (isinstance(data, dict) and not data):
                     return {
-                        "error": "AlphaFold returned an empty response",
+                        "error": "No MUTAGEN annotations available",
+                        "reason": (
+                            "Protein exists in AlphaFold DB but "
+                            "has no MUTAGEN annotations from UniProt"
+                        ),
                         "endpoint": url,
                         "query": arguments,
                     }
@@ -124,4 +161,7 @@ class AlphaFoldRESTTool(BaseTool):
                 }
 
         # Fallback for non-JSON output
-        return {"data": resp.text, "metadata": {"endpoint": url, "query": arguments}}
+        return {
+            "data": resp.text,
+            "metadata": {"endpoint": url, "query": arguments},
+        }
